#
# spec file for package python-python-dateutil
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-python-dateutil
Version:        2.6.1
Release:        lp150.1.9
Summary:        A Python Datetime Library
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            https://dateutil.readthedocs.org/en/latest/
Source0:        https://files.pythonhosted.org/packages/source/p/python-dateutil/python-dateutil-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools} >= 18.0.1
BuildRequires:  %{python_module six} >= 1.9.0
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-six >= 1.9.0
%ifpython2
Obsoletes:      %{oldpython}-dateutil < %{version}
Provides:       %{oldpython}-dateutil = %{version}
%endif
%ifpython3
Obsoletes:      python3-dateutil < %{version}
Provides:       python3-dateutil = %{version}
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
The python dateutil module provides powerful extensions to the standard
datetime module.

* Computing of relative deltas (next month, next year, next monday,
   last week of month, etc.)

* Computing of relative deltas between two given dates and/or
   datetime objects

* Computing of dates based on very flexible recurrence rules, using
   a superset of the iCalendar specification. Parsing of RFC strings
   is supported as well.

* Generic parsing of dates in almost any string format.

* Timezone (tzinfo) implementations for tzfile(5) format files
   (/etc/localtime, /usr/share/zoneinfo, etc.), TZ environment
   string (in all known formats), iCalendar format files, given
   ranges (with help from relative deltas), local machine timezone,
   fixed offset timezone, UTC timezone, and Windows registry-based
   time zones.

* Internal up-to-date world timezone information based on Olson's
   database.

* Computing of Easter Sunday dates for any given year, using Western,
Orthodox or Julian algorithms.

%prep
%setup -q -n python-dateutil-%{version}
#cleanup and MSdos style end of line separators
sed -i 's/\r$//' LICENSE NEWS PKG-INFO README.rst
rm -f setup.cfg

%build
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py test

%files %{python_files}
%defattr(-,root,root)
%doc LICENSE NEWS PKG-INFO README.rst
%{python_sitelib}/dateutil/
%{python_sitelib}/python_dateutil-%{version}-py*.egg-info

%changelog
* Mon Jul 10 2017 aloisio@gmx.com
- Update to version 2.6.1
  * Updated zoneinfo file to 2017b. (gh pr #395)
  * Added Python 3.6 to CI testing (gh pr #365)
  * Removed duplicate test name that was preventing a test from
    being run.
  * Reported and fixed by @jdufresne (gh pr #371)
  * Fixed testing of folds and gaps, particularly on Windows (gh
    pr #392)
  * Fixed deprecated escape characters in regular expressions.
    Reported by @nascheme and @thierryba (gh issue #361), fixed by
    @thierryba (gh pr #358)
  * Many PEP8 style violations and other code smells were fixed
    by @jdufresne (gh prs #358, #363, #364, #366, #367, #368, #372,
    [#374], #379, #380, #398)
  * Improved performance of tzutc and tzoffset objects. (gh pr
    [#391])
  * Fixed issue with several time zone classes around DST
    transitions in any zones with +0 standard offset (e.g.
    Europe/London) (gh issue #321, pr #390)
  * Fixed issue with fuzzy parsing where tokens similar to AM/PM
    that are in the end skipped were dropped in the
    fuzzy_with_tokens list. Reported and fixed by @jbrockmendel (gh
    pr #332).
  * Fixed issue with parsing dates of the form X m YY. Reported
    by @jbrockmendel. (gh issue #333, pr #393)
  * Added support for parser weekdays with less than 3
    characters. Reported by @arcadefoam (gh issue #343), fixed by
    @jonemo (gh pr #382)
  * Fixed issue with the addition and subtraction of certain
    relativedeltas. Reported and fixed by @kootenpv (gh issue #346,
    pr #347)
  * Fixed issue where the COUNT parameter of rrules was ignored
    if 0. Fixed by @mshenfield (gh pr #330), reported by @vaultah
    (gh issue #329).
  * Updated documentation to include the new tz methods. (gh pr
    [#324])
  * Update documentation to reflect that the parser can raise
    TypeError, reported and fixed by @tomchuk (gh issue #336, pr
    [#337])
  * Fixed an incorrect year in a parser doctest. Fixed by
    @xlotlu (gh pr #357)
  * Moved version information into _version.py and set up the
    versions more granularly.
- Use recommended source URL format
* Sat May  6 2017 toddrme2178@gmail.com
- Don't provide python2-dateutil, singlespec packages should use
  correct name.
* Tue Mar 28 2017 aloisio@gmx.com
- Converted to single-spec
- Enabled tests
- Spec cleanup
* Wed Nov  9 2016 tbechtold@suse.com
- Use https for Source
* Tue Nov  8 2016 aloisio@gmx.com
- Update to version 2.6.0
  * Added PEP-495-compatible methods to address ambiguous and
    imaginary dates in time zones in a backwards-compatible
    way. Ambiguous dates and times can now be safely represented
    by all dateutil time zones. Many thanks to Alexander
    Belopolski (@abalkin) and Tim Peters @tim-one for their
    inputs on how to address this. Original issues reported by
    Yupeng and @zed (lP: 1390262, gh issues #57, #112, #249,
    [#284], #286, prs #127, #225, #248, #264, #302).
  * Added new methods for working with ambiguous and imaginary
    dates to the tz module. datetime_ambiguous() determines if
    a datetime is ambiguous for a given zone and datetime_exists()
    determines if a datetime exists in a given zone.
    This works for all fold-aware datetimes, not just those
    provided by dateutil. (gh issue #253, gh pr #302)
  * Fixed an issue where dst() in Portugal in 1996 was
    returning the wrong value  in tz.tzfile objects. Reported
    by @abalkin (gh issue #128,  pr #225)
  * Fixed an issue where zoneinfo.ZoneInfoFile errors were not
    being properly deep-copied. (gh issue #226, pr #225)
  * Refactored tzwin and tzrange as a subclass of a common
    class, tzrangebase, as there was substantial overlapping
    functionality. As part of this change, tzrange and tzstr
    now expose a transitions() function, which returns the
    DST on and off transitions for a given year. (gh issue
    [#260], pr #302)
  * Deprecated zoneinfo.gettz() due to confusion with
    tz.gettz(), in favor of get() method of
    zoneinfo.ZoneInfoFile objects. (gh issue #11, pr #310)
  * For non-character, non-stream arguments, parser.parse now
    raises TypeError instead of AttributeError. (gh issues
    [#171], #269, pr #247)
  * Fixed an issue where tzfile objects were not properly
    handling dst() and tzname() when attached to
    datetime.time objects. Reported by @ovacephaloid.
    (gh issue #292, pr #309)
  * /usr/share/lib/zoneinfo was added to TZPATHS for
    compatibility with Solaris systems. Reported by @dhduvall
    (gh issue #276, pr #307)
  * tzoffset and tzrange objects now accept either a number of
    seconds or a datetime.timedelta() object wherever
    previously only a  number of seconds was allowed.
    (gh pr #264, #277)
  * datetime.timedelta objects can now be added to
    relativedelta objects. Reported and added by Alec Nikolas
    Reiter (@justanr) (gh issue #282, pr #283
  * Refactored relativedelta.weekday and rrule.weekday into a
    common base class to reduce code duplication.
    (gh issue #140, pr #311)
  * An issue where the WKST parameter was improperly rendering
    in str(rrule) was reported and fixed by Daniel LePage
    (@dplepage). (gh issue  #262, pr #263)
  * A replace() method has been added to rrule objects by
    @jendas1, which creates new rrule with modified attributes,
    analogous to datetime.replace (gh pr #167)
  * Made some significant performance improvements to rrule
    objects in Python 2.x (gh pr #245)
  * All classes defining equality functions now return
    NotImplemented when  compared to unsupported classes,
    rather than raising TypeError, to allow other classes to
    provide fallback support. (gh pr #236)
  * Several classes have been marked as explicitly unhashable
    to maintain identical behavior between Python 2 and 3.
    Submitted by Roy Williams (@rowillia) (gh pr #296)
  * Trailing whitespace in easter.py has been removed.
    Submitted by @OmgImAlexis (gh pr #299)
  * Windows-only batch files in build scripts had line endings
    switched to CRLF. (gh pr #237)
  * @adamchainz updated the documentation links to reflect
    that the canonical location for readthedocs links is now
    at .io, not .org. (gh pr #272)
  * Made some changes to the CI and codecov to test against
    newer versions of Python and pypy, and to adjust the code
    coverage  requirements. For the moment, full pypy3
    compatibility is not supported until a new release is
    available, due to upstream bugs in the old version
    affecting PEP-495 support. (gh prs #265, #266, #304, #308)
  * The full PGP signing key fingerprint was added to the
    README.md in favor of the previously used long-id.
    Reported by @valholl (gh issue #287, pr #304)
  * Updated zoneinfo to 2016i. (gh issue #298, gh pr #306)
* Fri Mar  4 2016 tbechtold@suse.com
- Fix Obsoletes. No version upgrade was done during renaming.
* Fri Feb 26 2016 tbechtold@suse.com
- Rename package to python-python-dateutil . It's openSUSE policy
  to use the $pypi name with the python prefix.
* Thu Aug 13 2015 Greg.Freemyer@gmail.com
- update url in specfile
- use sed to eliminate MS-DOS style end of lines
- update to version 2.4.2:
  * Updated zoneinfo to 2015b.
  * Fixed issue with parsing of tzstr on Python 2.7.x; tzstr will now
    be decoded if not a unicode type. gh #51 (lp:1331576), gh pr #55.
  * Fix a parser issue where AM and PM tokens were showing up in fuzzy
    date stamps, triggering inappropriate errors. gh #56 (lp:
    1428895), gh pr #63.
  * Missing function "setcachsize" removed from zoneinfo __all__ list
    by @ryanss, fixing an issue with wildcard imports of
    dateutil.zoneinfo. (gh pr #66).
  * (PyPi only) Fix an issue with source distributions not including
    the test suite.
- changes from version 2.4.1:
  * Added explicit check for valid hours if AM/PM is specified in
    parser. (gh pr #22, issue #21)
  * Fix bug in rrule introduced in 2.4.0 where byweekday parameter was
    not handled properly. (gh pr #35, issue #34)
  * Fix error where parser allowed some invalid dates, overwriting
    existing hours with the last 2-digit number in the string. (gh pr
    [#32], issue #31)
  * Fix and add test for Python 2.x compatibility with boolean
    checking of relativedelta objects. Implemented by @nimasmi (gh pr
    [#43]) and Céic Krier (lp: 1035038)
  * Replaced parse() calls with explicit datetime objects in unit
    tests unrelated to parser. (gh pr #36)
  * Changed private _byxxx from sets to sorted tuples and fixed one
    currently unreachable bug in _construct_byset. (gh pr #54)
  * Additional documentation for parser (gh pr #29, #33, #41) and
    rrule.
  * Formatting fixes to documentation of rrule and README.rst.
  * Updated zoneinfo to 2015a.
- changes from version 2.4.0:
  * Fix an issue with relativedelta and freezegun (lp:1374022)
  * Fix tzinfo in windows for timezones without dst (lp:1010050, gh
    [#2])
  * Ignore missing timezones in windows like in POSIX
  * Fix minimal version requirement for six (gh #6)
  * Many rrule changes and fixes by @pganssle (gh pull requests #13
    [#14] #17), including defusing some infinite loops (gh #4)
- changes from version 2.3:
  * Cleanup directory structure, moved test.py to
    dateutil/tests/test.py
  * Changed many aspects of dealing with the zone info file. Instead
    of a cache, all the zones are loaded to memory, but symbolic links
    are loaded only once, so not much memory is used.
  * The package is now zip-safe, and universal-wheelable, thanks to
    changes in the handling of the zoneinfo file.
  * Fixed tzwin silently not imported on windows python2
  * New maintainer, together with new hosting: GitHub, Travis,
    Read-The-Docs
* Mon Jul 27 2015 aloisio@gmx.com
- Update to version 2.2:
  * Updated zoneinfo to 2013h
  * fuzzy_with_tokens parse addon from Christopher Corley
  * Bug with LANG=C fixed by Mike Gilbert
- Aligned requirement version with PyPI
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jun  6 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  Look at the LICENSE file
* Wed Jun  6 2012 toddrme2178@gmail.com
- Added python-six requires and buildrequires.  dateutil will build
  without out, but packaged down the dependency chain will fail
  if it isn't installed
* Sun Jun  3 2012 os-dev@jacraig.com
- Update to version 2.1
  * See NEWS for changes
* Fri Apr 27 2012 toddrme2178@gmail.com
- Fix building python 3 package on openSUSE 11.4
* Thu Apr 26 2012 toddrme2178@gmail.com
- Add python 3 package
* Tue Apr 20 2010 cstender@novell.com
- updated to version 1.5
  * See NEWS for all changes and fixes
* Thu Aug 13 2009 cstender@novell.com
- build as noarch
* Tue Sep  9 2008 cstender@suse.de
- add python-setuptools to BuildRequire
- updated package to version 1.4.1
  o See NEWS for all changes and fixes
* Fri Oct 20 2006 dgollub@suse.de
- initial version of python-dateutil (1.1)
